Coverage for pygeodesy/deprecated/rhumbBase.py: 100%

1

2# -*- coding: utf-8 -*-

3

4 u'''DEPRECATED on 2023.11.26, use module L{pygeodesy.rhumb.bases} instead.

5'''

6

7 from pygeodesy.rhumb.bases import * # noqa: F403

8

9 __all__ = () # _ALL_LAZY.rhumb._bases

10 __version__ = '25.05.12'

11

12# **) MIT License

13#

14# Copyright (C) 2016-2026 -- mrJean1 at Gmail -- All Rights Reserved.

15#

16# Permission is hereby granted, free of charge, to any person obtaining a

17# copy of this software and associated documentation files (the "Software"),

18# to deal in the Software without restriction, including without limitation

19# the rights to use, copy, modify, merge, publish, distribute, sublicense,

20# and/or sell copies of the Software, and to permit persons to whom the

21# Software is furnished to do so, subject to the following conditions:

22#

23# The above copyright notice and this permission notice shall be included

24# in all copies or substantial portions of the Software.

25#

26# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS

27# OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,

28# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL

29# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR

30# OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE,

31# ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR

32# OTHER DEALINGS IN THE SOFTWARE.